@@ -24,7 +24,14 @@ class PLASMANM_EDITOR_EXPORT IPv4Widget : public SettingWidget
 {
     Q_OBJECT
 public:
-    enum MethodIndex { Automatic = 0, AutomaticOnlyIP, LinkLocal, Manual, Shared, Disabled };
+    enum MethodIndex {
+        Automatic = 0,
+        AutomaticOnlyIP,
+        LinkLocal,
+        Manual,
+        Shared,
+        Disabled
+    };
 
     explicit IPv4Widget(const NetworkManager::Setting::Ptr &setting = NetworkManager::Setting::Ptr(), QWidget *parent = nullptr, Qt::WindowFlags f = {});
     ~IPv4Widget() override;
